@@ -49,8 +49,13 @@
 
 package com.openexchange.appsuite;
 
+import java.util.Collection;
+import java.util.Collections;
+import com.openexchange.ajax.requesthandler.AJAXRequestData;
+import com.openexchange.ajax.requesthandler.Dispatcher;
 import com.openexchange.login.DefaultAppSuiteLoginRampUp;
 import com.openexchange.server.ServiceLookup;
+import com.openexchange.tools.session.ServerSession;
 
 /**
  * {@link AppSuiteLoginRampUp}
@@ -77,4 +82,51 @@ public class AppSuiteLoginRampUp extends DefaultAppSuiteLoginRampUp {
     public boolean contributesTo(String client) {
         return "open-xchange-appsuite".equals(client);
     }
+
+    @Override
+    protected Collection<Contribution> getExtendedContributions() {
+        Dispatcher ox = services.getService(Dispatcher.class);
+        if (null == ox) {
+            return Collections.emptyList();
+        }
+
+        return Collections.<Contribution> singletonList(new OnboardingDevicesContribution(ox));
+    }
+
+    // -------------------------------------------------------------------------------
+
+    private static final class OnboardingDevicesContribution extends AbstractDispatcherContribution {
+
+        private final String moduleName;
+
+        OnboardingDevicesContribution(Dispatcher ox) {
+            super(ox);
+            moduleName = "onboarding";
+        }
+
+        @Override
+        public String getKey() {
+            return "onboardingDevices";
+        }
+
+        @Override
+        protected String[] getParams() {
+            return new String[0];
+        }
+
+        @Override
+        protected String getModule() {
+            return moduleName;
+        }
+
+        @Override
+        protected String getAction() {
+            return "devices";
+        }
+
+        @Override
+        protected boolean isApplicable(ServerSession session, AJAXRequestData loginRequest, Dispatcher ox) {
+            return null != ox.lookupFactory(moduleName);
+        }
+    }
 }
